@@ -286,7 +286,7 @@
         stop("trend.d and trend.l must have similar specification\n")
     }
     else{
-      if((!is.null(class(trend.d)) && class(trend.d)=="trend.spatial") & (!is.null(class(trend.l)) && class(trend.l)=="trend.spatial")){
+      if((class(trend.d)=="trend.spatial") & (class(trend.l)=="trend.spatial")){
         if(ncol(trend.d) != ncol(trend.l))
           stop("trend.d and trend.l do not have the same number of columns")
       }
@@ -316,7 +316,7 @@
   else df.model <- Inf
   if(beta.prior == "normal"){
     if(beta.size > 1) ttvbetatt <- trend.data%*%beta.var%*%t(trend.data)
-    else ttvbetatt <- trend.data%*%t(trend.data)*beta.var
+    else ttvbetatt <- crossprod(t(trend.data))*beta.var
   }  
   else ttvbetatt <- NULL
   if(sigmasq.prior == "fixed"){     ### implies that phi is fixed !
@@ -325,9 +325,8 @@
                                try.another.decomposition = FALSE)$inverse
     if(beta.prior != "fixed"){
       ivtt <- invcov%*%trend.data
-      if(beta.prior == "normal") ittivtt <- solve.geoR(crossprod(trend.data, ivtt) + solve(beta.var))
-      else ittivtt <- solve.geoR(crossprod(trend.data, ivtt))
-      invcov <- invcov-ivtt%*%ittivtt%*%t(ivtt)
+      if(beta.prior == "normal") invcov <- invcov-ivtt%*%solve.geoR(crossprod(trend.data, ivtt) + solve(beta.var), t(ivtt))
+      else invcov <- invcov-ivtt%*%solve.geoR(crossprod(trend.data, ivtt), t(ivtt))
     }
   }
   if((phi.prior == "fixed") && (sigmasq.prior != "fixed")){
@@ -409,8 +408,7 @@
           }
         }
       }
-      if(is.R()) remove("temp.pred")
-      else remove("temp.pred", frame = sys.nframe())
+      remove("temp.pred")
       ## 
       if(messages.screen) cat("binom.krige.bayes: Prediction performed \n")
     }
